@@ -1,20 +1,4 @@
-import os
-import logging
-import PyPDF2
-from pdf2image import convert_from_path
-import cv2
-import pytesseract
-from PIL import Image
-import numpy as np
-import re
-import os
-import requests
-import cv2
-import pytesseract
-import numpy as np
-from PIL import Image
-import re
-
+from .functions import *
 def preprocess_for_ocr(image_path: str) -> np.ndarray:
     img = cv2.imread(image_path)
     gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
